@@ -1,5 +1,5 @@
-gamtol.int <- function (x, alpha = 0.05, P = 0.99, side = 1, method = c("HE", 
-    "WBE", "EXACT"), m = 50, log.gamma = FALSE) 
+gamtol.int <- function (x, alpha = 0.05, P = 0.99, side = 1, method = c("HE", "HE2",
+	    "WBE", "ELL", "KM", "EXACT", "OCT"), m = 50, log.gamma = FALSE) 
 {
     if (side != 1 && side != 2) {
         stop(paste("Must specify a one-sided or two-sided procedure!", 
