@@ -1,5 +1,5 @@
-normtol.int <- function (x, alpha = 0.05, P = 0.99, side = 1, method = c("HE", 
-    "WBE"), log.norm = FALSE) 
+normtol.int <- function (x, alpha = 0.05, P = 0.99, side = 1, method = c("HE", "HE2",
+	    "WBE", "ELL", "KM", "EXACT", "OCT"), m = 50, log.norm = FALSE) 
 {
     if (log.norm) 
         x <- log(x)
@@ -8,7 +8,7 @@ normtol.int <- function (x, alpha = 0.05, P = 0.99, side = 1, method = c("HE",
     n <- length(x)
     method <- match.arg(method)
     K <- invisible(K.factor(n = n, alpha = alpha, P = P, side = side, 
-        method = method))
+        method = method, m = m))
     lower <- x.bar - s * K
     upper <- x.bar + s * K
     if (log.norm) {
